@@ -4,16 +4,14 @@ Main interface for kinesisanalytics service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_kinesisanalytics import (
         Client,
         KinesisAnalyticsClient,
     )
 
-    session = boto3.Session()
-
-    client: KinesisAnalyticsClient = boto3.client("kinesisanalytics")
-    session_client: KinesisAnalyticsClient = session.client("kinesisanalytics")
+    session = Session()
+    client: KinesisAnalyticsClient = session.client("kinesisanalytics")
     ```
 """
 from .client import KinesisAnalyticsClient
